ufodiff
=======

ufodiff is a command line UFO source file modification and diff tool for collaborative typeface design/development projects.

It examines git repositories for changes to files that are part of the UFO source spec only (i.e. all file changes in the repository external to the UFO source code are not considered by the tool).

Documentation, source repository, and issue reporting available on `Github <https://github.com/source-foundry/ufodiff>`_ .